@@ -232,6 +232,16 @@ void AccountsController::setAutoLogin(const QString &id, const bool enable)
             m_worker->setAutoLogin(user, enable);
 }
 
+QString AccountsController::getOtherUserAutoLogin() const
+{
+    for (auto user : m_model->userList()) {
+        if (user->name() != currentUserName() && user->autoLogin()) {
+            return user->name();
+        }
+    }
+    return "";
+}
+
 bool AccountsController::isNoPassWordLoginVisable() const
 {
     return m_model->isNoPassWordLoginVisable();
@@ -742,6 +752,15 @@ QString AccountsController::currentUserId() const
     return QString();
 }
 
+bool AccountsController::curUserIsSysAdmin() const
+{
+    User *curUser = m_model->currentUser();
+    if (curUser)
+        return isSystemAdmin(curUser);
+
+    return false;
+}
+
 QStringList AccountsController::userTypes(bool createUser /* = false*/) const
 {
     QStringList types{ tr("Standard User"), tr("Administrator") };
