@@ -2,18 +2,19 @@
 //
 //SPDX-License-Identifier: GPL-3.0-or-later
 
-#include <QIcon>
-#include <QtQml>
-#include <DGuiApplicationHelper>
-
+#include "personalizationinterface.h"
 #include "operation/imagehelper.h"
+#include "operation/personalizationexport.hpp"
 #include "operation/treelandworker.h"
 #include "operation/x11worker.h"
-#include "personalizationinterface.h"
 #include "dccfactory.h"
 #include "model/thememodel.h"
 #include "utils.hpp"
 
+
+#include <QIcon>
+#include <QtQml>
+#include <DGuiApplicationHelper>
 ThemeVieweModel::ThemeVieweModel(QObject *parent)
     : QAbstractItemModel(parent)
     , m_themeModel(nullptr)
@@ -128,6 +129,8 @@ PersonalizationInterface::PersonalizationInterface(QObject *parent)
         m_work = new X11Worker(m_model, this);
     }
 
+    qmlRegisterType<PersonalizationExport>("org.deepin.dcc.personalization", 1, 0, "PersonalizationExport");
+
     m_globalThemeViewModel->setThemeModel(m_model->getGlobalThemeModel());
     m_iconThemeViewModel->setThemeModel(m_model->getIconModel());
     m_cursorThemeViewModel->setThemeModel(m_model->getMouseModel());
@@ -213,25 +216,30 @@ void PersonalizationInterface::handleCmdParam(PersonalizationExport::ModuleType
     } else if (type == PersonalizationExport::Wallpaper) {
         QString url;
         QString type;
+        QString monitor;
         url = paramMap.value("url");
         if (!isURI(url) && QFile::exists(url)) {
             url = QUrl::fromLocalFile(url).toString();
         }
         type = paramMap.value("type");
+        monitor = paramMap.value("monitor");
+        if (monitor.isEmpty()) {
+            monitor = m_model->getCurrentSelectScreen();
+        }
         if (url.isEmpty()) {
             return;
         }
         if (type == "lock") {
-            m_work->setLockBackForMonitor(m_model->getCurrentSelectScreen(), url, true);
+            m_work->setLockBackForMonitor(monitor, url, true);
         } else if (type == "desktop") {
-            m_work->setBackgroundForMonitor(m_model->getCurrentSelectScreen(), url, true);
+            m_work->setBackgroundForMonitor(monitor, url, true);
         } else if (type.isEmpty()) {
-            m_work->setLockBackForMonitor(m_model->getCurrentSelectScreen(), url, true);
-            m_work->setBackgroundForMonitor(m_model->getCurrentSelectScreen(), url, true);
+            m_work->setLockBackForMonitor(monitor, url, true);
+            m_work->setBackgroundForMonitor(monitor, url, true);
         }
     }
 }
 
 DCC_FACTORY_CLASS(PersonalizationInterface)
 
-#include "personalizationinterface.moc"
\ No newline at end of file
+#include "personalizationinterface.moc"
