@@ -4,6 +4,8 @@
 #ifndef PERSONALIZATIONWORKER_H
 #define PERSONALIZATIONWORKER_H
 
+#include "operation/personalizationexport.hpp"
+#include "operation/screensaverprovider.h"
 #include "operation/wallpaperworker.h"
 #include "personalizationmodel.h"
 
@@ -15,6 +17,7 @@
 #include <QJsonObject>
 
 #include <DConfig>
+#include <QScreen>
 
 class PersonalizationDBusProxy;
 class ThemeModel;
@@ -28,15 +31,29 @@ public:
     void onGetList();
     void refreshTheme();
     void refreshFont();
+    bool checkWallpaperLockStatus();
 
 public Q_SLOTS:
     void setDiabledCompactToTitleHeight();
     void setScrollBarPolicy(int policy);
     void setCompactDisplay(bool value);
     void goDownloadTheme();
+    QScreen *getScreen(const QString &screenName);
 
     // 设置给Appearance分别在深色和浅色下的活动色
     void setActiveColors(const QString &activeColors);
+    void addCustomWallpaper(const QString &url);
+    void addSolidWallpaper(const QColor &color);
+    void deleteWallpaper(const QString &str);
+    void setScreenSaver(const QString &value);
+    void setWallpaperSlideShow(const QString &monitorName, const QString &sliderShow);
+
+    void startScreenSaverPreview();
+    void stopScreenSaverPreview();
+    void setLockScreenAtAwake(bool value);
+    void setScreenSaverIdleTime(int value);
+    void setCurrentScreenSaverPicMode(const QString &mode);
+    void requestScreenSaverConfig(const QString &name);
 
     virtual void setDefaultByType(const QString &type, const QString &value);
     virtual void setDefault(const QJsonObject &value);
@@ -52,6 +69,7 @@ public Q_SLOTS:
     virtual void setAppearanceTheme(const QString &id, bool keepAuto = false);
     virtual void setIconTheme(const QString &id);
     virtual void setCursorTheme(const QString &id);
+    virtual void setWallpaperForMonitor(const QString &screen, const QString &url, bool isDark, PersonalizationExport::WallpaperSetOption option);
     virtual void setBackgroundForMonitor(const QString &screenName, const QString &url, bool isDark);
     virtual void setLockBackForMonitor(const QString &screenName, const QString &url, bool isDark);
 
@@ -69,6 +87,10 @@ private Q_SLOTS:
     void onCompactDisplayChanged(int value);
     void onWindowEffectChanged(int value);
     void onScreensChanged();
+    void onCurrentScreenSaverChanged(const QString &value);
+    void onLockScreenAtAwakeChanged(bool value);
+    void onLinePowerScreenSaverTimeoutChanged(int value);
+    void onWallpaperSlideShowChanged();
 
 protected:
     virtual void onWallpaperUrlsChanged();
@@ -93,6 +115,7 @@ protected:
 
 private:
     WallpaperWorker *m_wallpaperWorker;
+    ScreensaverProvider *m_screenSaverProvider;
     Dtk::Core::DConfig *m_personalizationConfig;
     Dtk::Core::DConfig *m_dtkConfig;
 
